==> ideaIC-183.2407.10-sources.jar: org/jetbrains/plugins/gradle/action/GradleToolWindowHelpAction.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.gradle.action;

import com.intellij.ide.actions.ContextHelpAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.plugins.gradle.util.GradleConstants;

/**
 * @author Denis Zhdanov
 * @since 3/17/12 2:34 PM
 */
public class GradleToolWindowHelpAction extends ContextHelpAction {

  @Override
  public void update(@NotNull AnActionEvent event) {
    final Project project = event.getProject();
    if (project == null) {
      event.getPresentation().setVisible(false);
      return;
    }

    // TODO den implement
//    if (StringUtil.isEmpty(GradleSettings.getInstance(project).getLinkedExternalProjectPath())) {
//      event.getPresentation().setVisible(false);
//      return;
//    }
    event.getPresentation().setVisible(true);
    super.update(event);
  }

  @Override
  protected String getHelpId(DataContext dataContext) {
    return GradleConstants.HELP_TOPIC_TOOL_WINDOW;
  }
}

==> ideaIC-2017.2.6-sources.jar: org/jetbrains/plugins/gradle/action/GradleToolWindowHelpAction.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.gradle.action;

import com.intellij.ide.actions.ContextHelpAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.DataContext;
import com.intellij.openapi.project.Project;
import org.jetbrains.plugins.gradle.util.GradleConstants;

/**
 * @author Denis Zhdanov
 * @since 3/17/12 2:34 PM
 */
public class GradleToolWindowHelpAction extends ContextHelpAction {

  @Override
  public void update(AnActionEvent event) {
    final Project project = event.getProject();
    if (project == null) {
      event.getPresentation().setVisible(false);
      return;
    }

    // TODO den implement
//    if (StringUtil.isEmpty(GradleSettings.getInstance(project).getLinkedExternalProjectPath())) {
//      event.getPresentation().setVisible(false);
//      return;
//    }
    event.getPresentation().setVisible(true);
    super.update(event);
  }

  @Override
  protected String getHelpId(DataContext dataContext) {
    return GradleConstants.HELP_TOPIC_TOOL_WINDOW;
  }
}
